@@ -23,4 +23,4 @@ SOFTWARE."""
 from .aioclient import WaifuAioClient
 from .exceptions import *
 from .utils import requires_token, APIBaseURL
-from .moduleinfo import *
\ No newline at end of file
+from .moduleinfo import __version__,__author__
\ No newline at end of file
