@@ -108,10 +108,35 @@ class WaifuAioClient:
         """process the request for a specific tag and check if everything is correct."""
         params=self._create_params(exclude = exclude, gif = gif, many = many, top = top)
         headers=self._create_params(**{'User-Agent': self.appname})
-        infos= await self._make_request(f"{APIBaseURL}{type_}/{tag}/", 'get', params = params, headers = headers)
+        type_and_tag="random" if type_ is None or tag is None else type_+"/"+tag
+        infos= await self._make_request(f"{APIBaseURL}{type_and_tag}/", 'get', params = params, headers = headers)
         if raw:
             return infos
-        return [im['url'] for im in infos['tags'][0]['images']] if many else infos['tags'][0]['images'][0]['url']
+        return [im['url'] for im in infos['images']] if many else infos['images'][0]['url']
+
+
+
+    async def random(
+        self,
+        raw: bool = False,
+        exclude: List[str] = None,
+        gif: bool = None,
+        many: bool = None,
+        top: bool = None
+    ) -> Dict:
+        """Gets a single or multiple images from the API.            
+        Kwargs:
+            raw: if whether or not you want the wrapper to return the entire json or just the picture url.
+            many: Get multiples images instead of a single one (see the api docs for the exact number).
+            top: Order by most liked image(s).
+            exclude: A list of URL's that you do not want to get.
+            gif: If False is provided prevent the API to return .gif files, else if True is provided force it to do so if nothing is provided then it is completly random.
+        Returns:
+            A single or a list of image URL's.
+        Raises:
+            APIException: If the API response contains an error.
+        """
+        return await self._fetchtag(None,None, raw, exclude, gif, many, top)
 
     async def sfw(
         self,
@@ -131,14 +156,13 @@ class WaifuAioClient:
             many: Get multiples images instead of a single one (see the api docs for the exact number).
             top: Order by most liked image(s).
             exclude: A list of URL's that you do not want to get.
-            raw: If False is provided prevent the API to return .gif files, else if True is provided force it to do so if nothing is provided then it is completly random.
+            gif: If False is provided prevent the API to return .gif files, else if True is provided force it to do so if nothing is provided then it is completly random.
         Returns:
             A single or a list of image URL's.
         Raises:
             APIException: If the API response contains an error.
         """
-        data = await self._fetchtag('sfw', tag, raw, exclude, gif, many, top)
-        return data
+        return await self._fetchtag('sfw', tag, raw, exclude, gif, many, top)
 
     async def nsfw(
         self,
